# Global config

{ config, lib, pkgs, ... }:

{

	options.riley = with lib; {

		ide = mkOption {
			type = types.bool;
			description = ''
				Enable IDE-like plugins such as language servers for Rust, Haskell and
				Nix in the editor, and configure accordingly.
			'';
			default = true;
		};
		
		gui = mkOption {
			type = types.bool;
			description = ''
				Enables GUI applications, a display server, audio server and related services.
			'';
			default = true;
		};

	};

	imports = [

    	<home-manager/nixos>

		./kakoune
		./display
		
		./alacritty.nix
		./fonts.nix
		./git.nix
		
	];
    
    config = {

    	environment.systemPackages = with pkgs; [

    		# Web utils

    		wget
    		curl
    		git

    		# Coreutils

    		ripgrep
    		bottom
    		skim
    		exa
    		bat
    		lf
    		fd
    		
    	];

    	boot = {
    		loader.systemd-boot = {
    			enable = true;
    			editor = false;
    			configurationLimit = 10;
    		};

    		loader.efi = {
    			canTouchEfiVariables = true;
    		};
    		
    		cleanTmpDir = true;
    	};

    	networking = {
    		firewall.enable = false;
    		useDHCP = false;
    	};

    	nixpkgs.config.allowUnfree = true;

        users.users."riley" = {
            isNormalUser = true;
            extraGroups = [ "wheel" ]; # Enable ‘sudo’ for the user.
        };

    };
}
